/**
 * @file
 * JavaScript for the Views Ooyala shared player output.
 */
(function ($) {
  setTimeout('', 1); //does the timeout work?
  jQuery.each(Drupal.settings.ooyalaSharedPlayerCodes, function(i, val) {
    $('#' + Drupal.settings.ooyalaSharedPlayer + "-" + i).click(function() {
      document.getElementById(Drupal.settings.ooyalaSharedPlayer).setQueryStringParameters({embedCode: val});
    });
  });

  // If the ooyala_player.js hasn't been loaded yet we initialize the object so
  // that we can added to it.
  Drupal.ooyala = Drupal.ooyala || {'listeners': {}};

  /**
   * Dispatch Ooyala player callback events to all registered listeners.
   *
   * Listeners are registered in the Drupal.ooyala.listeners object as follows.
   * @code
   *    Drupal.ooyala.listeners = function (player, eventName, p) {
   *      ...
   *    };
   * @endcode
   *
   * All listeners will recieve the following arguments.
   * - player: The DOM object representing the Ooyala player that is recieving
   *   the event notification.
   * - eventName: The event name as sent by Ooyala.
   * - p: Extra notification parameters.
   *
   * Read the Ooyala javascript API documentation for a complete list of events
   * and their possible extra notification parameters.
   * @link http://www.ooyala.com/support/docs/player_api#javascript
   */
  Drupal.ooyala.notifyListeners = function(playerId, eventName, p) {
    var player = document.getElementById(playerId);
    jQuery.each(Drupal.ooyala.listeners, function() {
      this(player, eventName, p);
    });
  };

  /**
   * Add an event responder to Drupal.ooyala.listners list.
   */
  Drupal.ooyala.listeners.shared_player = function(player, eventName, p) {
    playerId = $(player).attr('id');
    switch(eventName) {
      case 'embedCodeChanged':
        $('#title-' + playerId ).empty().append(p.title);
        $('#description-' + playerId ).empty().append(p.description);
        break;
      case 'loadComplete':
        var description = document.getElementById(Drupal.settings.ooyalaSharedPlayer).getCurrentItem();
        $('#title-' + playerId ).empty().append(description.title);
        $('#description-' + playerId ).empty().append(description.description);     
        break;
    }
    return;
  }

  /**
   * Callback function for Ooyala Javascript API. Recieves events for the player
   * and then dispatches them so that other modules can interact with the player.
   *
   * @see Drupal.ooyala.notifyListeners()
   */
  function receiveOoyalaEvent(playerId, eventName, p) {
    Drupal.ooyala.notifyListeners(playerId, eventName, p);
    return;
  }
})(jQuery);
